@@ -22,10 +22,11 @@
 #ifndef INCLUDED_GR_FXPT_H
 #define INCLUDED_GR_FXPT_H
 
+#include <gr_core_api.h>
 #include <gr_types.h>
 
 /*!
- * \brief fixed point sine and cosine and friends.
+ * \brief fixed point sine and cosine and friend GR_CORE_APIs.
  * \ingroup misc
  *
  *   fixed pt	radians
@@ -35,13 +36,13 @@
  *  2**31-1        pi - epsilon
  *
  */
-class gr_fxpt
+class GR_CORE_API gr_fxpt
 {
   static const int WORDBITS = 32;
   static const int NBITS = 10;
   static const float s_sine_table[1 << NBITS][2];
-  static const float PI = 3.14159265358979323846;
-  static const float TWO_TO_THE_31 = 2147483648.0;
+  static const float PI;
+  static const float TWO_TO_THE_31;
 public:
 
   static gr_int32
