@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2004,206 Free Software Foundation, Inc.
+ * Copyright 2004,2006,2011 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -23,13 +23,16 @@
 #ifndef INCLUDED_GR_PLL_CARRIERTRACKING_CC_H
 #define INCLUDED_GR_PLL_CARRIERTRACKING_CC_H
 
+#include <gr_core_api.h>
 #include <gr_sync_block.h>
+#include <gri_control_loop.h>
 
 class gr_pll_carriertracking_cc;
 typedef boost::shared_ptr<gr_pll_carriertracking_cc> gr_pll_carriertracking_cc_sptr;
 
-gr_pll_carriertracking_cc_sptr gr_make_pll_carriertracking_cc (float alpha, float beta,
-					       float max_freq, float min_freq);
+GR_CORE_API gr_pll_carriertracking_cc_sptr gr_make_pll_carriertracking_cc (float loop_bw,
+							       float max_freq,
+							       float min_freq);
 /*!
  * \brief Implements a PLL which locks to the input frequency and outputs the 
  * input signal mixed with that carrier.
@@ -41,19 +44,20 @@ gr_pll_carriertracking_cc_sptr gr_make_pll_carriertracking_cc (float alpha, floa
  * the input and outputs that signal, downconverted to DC
  * 
  * All settings max_freq and min_freq are in terms of radians per sample, 
- * NOT HERTZ.  Alpha is the phase gain (first order, units of radians per radian) 
- * and beta is the frequency gain (second order, units of radians per sample per radian)
+ * NOT HERTZ.  The loop bandwidth determins the lock range and should be set
+ * around pi/200 -- 2pi/100.
  * \sa gr_pll_freqdet_cf, gr_pll_carriertracking_cc
  */
 
-class gr_pll_carriertracking_cc : public gr_sync_block
+class GR_CORE_API gr_pll_carriertracking_cc : public gr_sync_block, public gri_control_loop
 {
-  friend gr_pll_carriertracking_cc_sptr gr_make_pll_carriertracking_cc (float alpha, float beta,
-							float max_freq, float min_freq);
+  friend GR_CORE_API gr_pll_carriertracking_cc_sptr gr_make_pll_carriertracking_cc (float loop_bw,
+									float max_freq,
+									float min_freq);
 
-  float d_alpha,d_beta,d_max_freq,d_min_freq,d_phase,d_freq,d_locksig,d_lock_threshold;
+  float d_locksig,d_lock_threshold;
   bool d_squelch_enable;
-  gr_pll_carriertracking_cc (float alpha, float beta, float max_freq, float min_freq);
+  gr_pll_carriertracking_cc (float loop_bw, float max_freq, float min_freq);
 
   int work (int noutput_items,
 	    gr_vector_const_void_star &input_items,
