@@ -22,13 +22,14 @@
 #ifndef INCLUDED_GR_PROBE_AVG_MAG_SQRD_CF_H
 #define INCLUDED_GR_PROBE_AVG_MAG_SQRD_CF_H
 
+#include <gr_core_api.h>
 #include <gr_sync_block.h>
 #include <gr_single_pole_iir.h>
 
 class gr_probe_avg_mag_sqrd_cf;
 typedef boost::shared_ptr<gr_probe_avg_mag_sqrd_cf> gr_probe_avg_mag_sqrd_cf_sptr;
 
-gr_probe_avg_mag_sqrd_cf_sptr
+GR_CORE_API gr_probe_avg_mag_sqrd_cf_sptr
 gr_make_probe_avg_mag_sqrd_cf (double threshold_db, double alpha = 0.0001);
 
 /*!
@@ -43,14 +44,14 @@ gr_make_probe_avg_mag_sqrd_cf (double threshold_db, double alpha = 0.0001);
  * can be retrieved with the level and unmuted accessors.
  *
  */
-class gr_probe_avg_mag_sqrd_cf : public gr_sync_block
+class GR_CORE_API gr_probe_avg_mag_sqrd_cf : public gr_sync_block
 {
   double					d_threshold;
   gr_single_pole_iir<double,double,double>	d_iir;
   bool						d_unmuted;
   double					d_level;
 
-  friend gr_probe_avg_mag_sqrd_cf_sptr
+  friend GR_CORE_API gr_probe_avg_mag_sqrd_cf_sptr
   gr_make_probe_avg_mag_sqrd_cf (double threshold_db, double alpha);
 
   gr_probe_avg_mag_sqrd_cf (double threshold_db, double alpha);
