@@ -47,6 +47,24 @@ static int my_fftw_read_char(void *f) { return fgetc((FILE *) f); }
 #include <boost/filesystem/path.hpp>
 namespace fs = boost::filesystem;
 
+gr_complex *
+gri_fft_malloc_complex(int size)
+{
+  return (gr_complex*)fftwf_malloc(sizeof(gr_complex)*size);
+}
+
+float *
+gri_fft_malloc_float(int size)
+{
+  return (float*)fftwf_malloc(sizeof(float)*size);
+}
+
+void
+gri_fft_free(void *b)
+{
+  fftwf_free(b);
+}
+
 boost::mutex &
 gri_fft_planner::mutex()
 {
@@ -77,6 +95,22 @@ gri_fftw_import_wisdom ()
   }
 }
 
+static void
+gri_fftw_config_threading (int nthreads)
+{
+  static int fftw_threads_inited = 0;
+  
+#ifdef FFTW3F_THREADS
+  if (fftw_threads_inited == 0)
+  {
+	  fftw_threads_inited = 1;
+	  fftwf_init_threads();
+  }
+  
+  fftwf_plan_with_nthreads(nthreads);
+#endif
+}
+
 static void
 gri_fftw_export_wisdom ()
 {
@@ -94,7 +128,7 @@ gri_fftw_export_wisdom ()
 
 // ----------------------------------------------------------------
 
-gri_fft_complex::gri_fft_complex (int fft_size, bool forward)
+gri_fft_complex::gri_fft_complex (int fft_size, bool forward, int nthreads)
 {
   // Hold global mutex during plan construction and destruction.
   gri_fft_planner::scoped_lock	lock(gri_fft_planner::mutex());
@@ -115,7 +149,10 @@ gri_fft_complex::gri_fft_complex (int fft_size, bool forward)
     throw std::runtime_error ("fftwf_malloc");
   }
 
+  d_nthreads = nthreads;
+  gri_fftw_config_threading (nthreads);
   gri_fftw_import_wisdom ();	// load prior wisdom from disk
+
   d_plan = fftwf_plan_dft_1d (fft_size,
 			      reinterpret_cast<fftwf_complex *>(d_inbuf), 
 			      reinterpret_cast<fftwf_complex *>(d_outbuf),
@@ -139,6 +176,18 @@ gri_fft_complex::~gri_fft_complex ()
   fftwf_free (d_outbuf);
 }
 
+void 
+gri_fft_complex::set_nthreads(int n)
+{
+  if (n <= 0)
+    throw std::out_of_range ("gri_fftw: invalid number of threads");
+  d_nthreads = n;
+
+#ifdef FFTW3F_THREADS
+  fftwf_plan_with_nthreads(d_nthreads);
+#endif
+}
+
 void
 gri_fft_complex::execute ()
 {
@@ -147,7 +196,7 @@ gri_fft_complex::execute ()
 
 // ----------------------------------------------------------------
 
-gri_fft_real_fwd::gri_fft_real_fwd (int fft_size)
+gri_fft_real_fwd::gri_fft_real_fwd (int fft_size, int nthreads)
 {
   // Hold global mutex during plan construction and destruction.
   gri_fft_planner::scoped_lock	lock(gri_fft_planner::mutex());
@@ -168,7 +217,10 @@ gri_fft_real_fwd::gri_fft_real_fwd (int fft_size)
     throw std::runtime_error ("fftwf_malloc");
   }
 
+  d_nthreads = nthreads;
+  gri_fftw_config_threading (nthreads);
   gri_fftw_import_wisdom ();	// load prior wisdom from disk
+  
   d_plan = fftwf_plan_dft_r2c_1d (fft_size,
 				  d_inbuf,
 				  reinterpret_cast<fftwf_complex *>(d_outbuf),
@@ -191,6 +243,18 @@ gri_fft_real_fwd::~gri_fft_real_fwd ()
   fftwf_free (d_outbuf);
 }
 
+void 
+gri_fft_real_fwd::set_nthreads(int n)
+{
+  if (n <= 0)
+    throw std::out_of_range ("gri_fftw: invalid number of threads");
+  d_nthreads = n;
+
+#ifdef FFTW3F_THREADS
+  fftwf_plan_with_nthreads(d_nthreads);
+#endif
+}
+
 void
 gri_fft_real_fwd::execute ()
 {
@@ -199,7 +263,7 @@ gri_fft_real_fwd::execute ()
 
 // ----------------------------------------------------------------
 
-gri_fft_real_rev::gri_fft_real_rev (int fft_size)
+gri_fft_real_rev::gri_fft_real_rev (int fft_size, int nthreads)
 {
   // Hold global mutex during plan construction and destruction.
   gri_fft_planner::scoped_lock	lock(gri_fft_planner::mutex());
@@ -220,11 +284,13 @@ gri_fft_real_rev::gri_fft_real_rev (int fft_size)
     throw std::runtime_error ("fftwf_malloc");
   }
 
+  d_nthreads = nthreads;
+  gri_fftw_config_threading (nthreads);
+  gri_fftw_import_wisdom ();	// load prior wisdom from disk
+  
   // FIXME If there's ever a chance that the planning functions
   // will be called in multiple threads, we've got to ensure single
   // threaded access.  They are not thread-safe.
-  
-  gri_fftw_import_wisdom ();	// load prior wisdom from disk
   d_plan = fftwf_plan_dft_c2r_1d (fft_size,
 				  reinterpret_cast<fftwf_complex *>(d_inbuf),
 				  d_outbuf,
@@ -244,6 +310,18 @@ gri_fft_real_rev::~gri_fft_real_rev ()
   fftwf_free (d_outbuf);
 }
 
+void 
+gri_fft_real_rev::set_nthreads(int n)
+{
+  if (n <= 0)
+    throw std::out_of_range ("gri_fftw: invalid number of threads");
+  d_nthreads = n;
+
+#ifdef FFTW3F_THREADS
+  fftwf_plan_with_nthreads(d_nthreads);
+#endif
+}
+
 void
 gri_fft_real_rev::execute ()
 {
