@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2004,2009 Free Software Foundation, Inc.
+ * Copyright 2004,2009,2010,2011 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -23,9 +23,12 @@
 #ifndef INCLUDED_GR_BUFFER_H
 #define INCLUDED_GR_BUFFER_H
 
+#include <gr_core_api.h>
 #include <gr_runtime_types.h>
 #include <boost/weak_ptr.hpp>
 #include <gruel/thread.h>
+#include <gr_tags.h>
+#include <deque>
 
 class gr_vmcircbuf;
 
@@ -40,14 +43,14 @@ class gr_vmcircbuf;
  * \param sizeof_item is the size of an item in bytes.
  * \param link is the block that writes to this buffer.
  */
-gr_buffer_sptr gr_make_buffer (int nitems, size_t sizeof_item, gr_block_sptr link=gr_block_sptr());
+GR_CORE_API gr_buffer_sptr gr_make_buffer (int nitems, size_t sizeof_item, gr_block_sptr link=gr_block_sptr());
 
 
 /*!
  * \brief Single writer, multiple reader fifo.
  * \ingroup internal
  */
-class gr_buffer {
+class GR_CORE_API gr_buffer {
  public:
 
   virtual ~gr_buffer ();
@@ -88,13 +91,33 @@ class gr_buffer {
 
   gruel::mutex *mutex() { return &d_mutex; }
 
+  uint64_t nitems_written() { return d_abs_write_offset; }
+
+
+  /*!
+   * \brief  Adds a new tag to the buffer.
+   * 
+   * \param tag        the new tag
+   */
+  void add_item_tag(const gr_tag_t &tag);
+
+  /*!
+   * \brief  Removes all tags before \p max_time from buffer
+   * 
+   * \param max_time        the time (item number) to trim up until.
+   */
+  void prune_tags(uint64_t max_time);
+
+  std::deque<gr_tag_t>::iterator get_tags_begin() { return d_item_tags.begin(); }
+  std::deque<gr_tag_t>::iterator get_tags_end() { return d_item_tags.end(); }
+
   // -------------------------------------------------------------------------
 
  private:
 
   friend class gr_buffer_reader;
-  friend gr_buffer_sptr gr_make_buffer (int nitems, size_t sizeof_item, gr_block_sptr link);
-  friend gr_buffer_reader_sptr gr_buffer_add_reader (gr_buffer_sptr buf, int nzero_preload, gr_block_sptr link);
+  friend GR_CORE_API gr_buffer_sptr gr_make_buffer (int nitems, size_t sizeof_item, gr_block_sptr link);
+  friend GR_CORE_API gr_buffer_reader_sptr gr_buffer_add_reader (gr_buffer_sptr buf, int nzero_preload, gr_block_sptr link);
 
  protected:
   char				       *d_base;		// base address of buffer
@@ -106,11 +129,15 @@ class gr_buffer {
   boost::weak_ptr<gr_block>		d_link;		// block that writes to this buffer
 
   //
-  // The mutex protects d_write_index, d_done and the d_read_index's in the buffer readers.
+  // The mutex protects d_write_index, d_abs_write_offset, d_done, d_item_tags 
+  // and the d_read_index's and d_abs_read_offset's in the buffer readers.
   //
   gruel::mutex				d_mutex;
   unsigned int				d_write_index;	// in items [0,d_bufsize)
+  uint64_t                              d_abs_write_offset; // num items written since the start
   bool					d_done;
+  std::deque<gr_tag_t>                  d_item_tags;
+  uint64_t                              d_last_min_items_read;
   
   unsigned
   index_add (unsigned a, unsigned b)
@@ -166,11 +193,11 @@ class gr_buffer {
  * \param nzero_preload -- number of zero items to "preload" into buffer.
  * \param link is the block that reads from the buffer using this gr_buffer_reader.
  */
-gr_buffer_reader_sptr 
+GR_CORE_API gr_buffer_reader_sptr 
 gr_buffer_add_reader (gr_buffer_sptr buf, int nzero_preload, gr_block_sptr link=gr_block_sptr());
 
 //! returns # of gr_buffers currently allocated
-long gr_buffer_ncurrently_allocated ();
+GR_CORE_API long gr_buffer_ncurrently_allocated ();
 
 
 // ---------------------------------------------------------------------------
@@ -180,7 +207,7 @@ long gr_buffer_ncurrently_allocated ();
  * \ingroup internal
  */
 
-class gr_buffer_reader {
+class GR_CORE_API gr_buffer_reader {
  public:
 
   ~gr_buffer_reader ();
@@ -220,22 +247,43 @@ class gr_buffer_reader {
   gruel::mutex *mutex() { return d_buffer->mutex(); }
 
 
+  uint64_t nitems_read() { return d_abs_read_offset; }
+
   /*!
    * \brief Return the block that reads via this reader.
+   *
    */
   gr_block_sptr link() { return gr_block_sptr(d_link); }
 
+
+  /*!
+   * \brief Given a [start,end), returns a vector all tags in the range.
+   *
+   * Get a vector of tags in given range. Range of counts is from start to end-1.
+   *
+   * Tags are tuples of:
+   *      (item count, source id, key, value)
+   *
+   * \param v            a vector reference to return tags into
+   * \param abs_start    a uint64 count of the start of the range of interest
+   * \param abs_end      a uint64 count of the end of the range of interest
+   */
+  void get_tags_in_range(std::vector<gr_tag_t> &v,
+			 uint64_t abs_start,
+			 uint64_t abs_end);
+
   // -------------------------------------------------------------------------
 
  private:
 
   friend class gr_buffer;
-  friend gr_buffer_reader_sptr 
+  friend GR_CORE_API gr_buffer_reader_sptr 
   gr_buffer_add_reader (gr_buffer_sptr buf, int nzero_preload, gr_block_sptr link);
 
 
   gr_buffer_sptr		d_buffer;
   unsigned int			d_read_index;	// in items [0,d->buffer.d_bufsize)
+  uint64_t                      d_abs_read_offset;  // num items seen since the start
   boost::weak_ptr<gr_block>	d_link;		// block that reads via this buffer reader
 
   //! constructor is private.  Use gr_buffer::add_reader to create instances
@@ -243,7 +291,7 @@ class gr_buffer_reader {
 };
 
 //! returns # of gr_buffer_readers currently allocated
-long gr_buffer_reader_ncurrently_allocated ();
+GR_CORE_API long gr_buffer_reader_ncurrently_allocated ();
 
 
 #endif /* INCLUDED_GR_BUFFER_H */
