@@ -29,6 +29,7 @@
 #include <gr_block_detail.h>
 #include <gr_buffer.h>
 #include <boost/thread.hpp>
+#include <boost/format.hpp>
 #include <iostream>
 #include <limits>
 #include <assert.h>
@@ -57,9 +58,8 @@ gr_single_threaded_scheduler::gr_single_threaded_scheduler (
   : d_blocks (blocks), d_enabled (true), d_log(0)
 {
   if (ENABLE_LOGGING){
-    char name[100];
-    snprintf(name, sizeof(name), "sst-%d.log", which_scheduler++);
-    d_log = new std::ofstream(name);
+    std::string name = str(boost::format("sst-%d.log") % which_scheduler++);
+    d_log = new std::ofstream(name.c_str());
     *d_log << "gr_single_threaded_scheduler: "
 	   << d_blocks.size ()
 	   << " blocks\n";
