@@ -23,6 +23,7 @@
 #ifndef INCLUDED_GR_TOP_BLOCK_IMPL_H
 #define INCLUDED_GR_TOP_BLOCK_IMPL_H
 
+#include <gr_core_api.h>
 #include <gr_scheduler.h>
 #include <gruel/thread.h>
 
@@ -34,14 +35,14 @@
  * decoupling of changes from dependent classes.
  *
  */
-class gr_top_block_impl
+class GR_CORE_API gr_top_block_impl
 {
 public:
   gr_top_block_impl(gr_top_block *owner);
   ~gr_top_block_impl();
 
   // Create and start scheduler threads
-  void start();
+  void start(int max_noutput_items=100000);
 
   // Signal scheduler threads to stop
   void stop();
@@ -57,6 +58,12 @@ public:
 
   // Dump the flowgraph to stdout
   void dump();
+
+  // Get the number of max noutput_items in the flowgraph
+  int max_noutput_items();
+  
+  // Set the maximum number of noutput_items in the flowgraph
+  void set_max_noutput_items(int nmax);
   
 protected:
     
@@ -69,6 +76,7 @@ protected:
   gruel::mutex                   d_mutex;	// protects d_state and d_lock_count
   tb_state			 d_state;
   int                            d_lock_count;
+  int                            d_max_noutput_items;
   
 private:
   void restart();
