@@ -86,16 +86,30 @@ fsm::fsm(const char *name)
   if((fsmfile=fopen(name,"r"))==NULL) 
     throw std::runtime_error ("fsm::fsm(const char *name): file open error\n");
     //printf("file open error in fsm()\n");
+
+  if(fscanf(fsmfile,"%d %d %d\n",&d_I,&d_S,&d_O) == EOF) {
+    if(ferror(fsmfile) != 0)
+      throw std::runtime_error ("fsm::fsm(const char *name): file read error\n");
+  }
   
-  fscanf(fsmfile,"%d %d %d\n",&d_I,&d_S,&d_O);
   d_NS.resize(d_I*d_S);
   d_OS.resize(d_I*d_S);
 
   for(int i=0;i<d_S;i++) {
-    for(int j=0;j<d_I;j++) fscanf(fsmfile,"%d",&(d_NS[i*d_I+j]));
+    for(int j=0;j<d_I;j++) {
+      if(fscanf(fsmfile,"%d",&(d_NS[i*d_I+j])) == EOF) {
+	if(ferror(fsmfile) != 0)
+	  throw std::runtime_error ("fsm::fsm(const char *name): file read error\n");
+      }
+    }
   }
   for(int i=0;i<d_S;i++) {
-    for(int j=0;j<d_I;j++) fscanf(fsmfile,"%d",&(d_OS[i*d_I+j]));
+    for(int j=0;j<d_I;j++) {
+      if(fscanf(fsmfile,"%d",&(d_OS[i*d_I+j])) == EOF) {
+	if(ferror(fsmfile) != 0)
+	  throw std::runtime_error ("fsm::fsm(const char *name): file read error\n");
+      }
+    }
   }
  
   generate_PS_PI();
@@ -118,7 +132,7 @@ fsm::fsm(int k, int n, const std::vector<int> &G)
     for(int j=0;j<n;j++) {
       int mem = -1;
       if(G[i*n+j]!=0)
-        mem=(int)(log(G[i*n+j])/log(2.0));
+        mem=(int)(log(double(G[i*n+j]))/log(2.0));
       if(mem>max_mem_x[i])
         max_mem_x[i]=mem;
       if(mem>max_mem)
@@ -403,7 +417,7 @@ void fsm::generate_TM()
       done = find_es(s);
       attempts ++;
     }
-    if (done == false) {
+    if (done == false && d_S > 1) {
       //throw std::runtime_error ("fsm::generate_TM(): FSM appears to be disconnected\n");
       printf("fsm::generate_TM(): FSM appears to be disconnected\n");
       printf("state %d cannot be reached from all other states\n",s);
